@@ -12,7 +12,7 @@ using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN Blog::Private
 {
-  public:
+public:
     Private();
 
     static BlogPtr fromJSON(const QVariant &json);
@@ -23,8 +23,8 @@ class Q_DECL_HIDDEN Blog::Private
     QDateTime published;
     QDateTime updated;
     QUrl url;
-    uint postsCount;
-    uint pagesCount;
+    uint postsCount = 0;
+    uint pagesCount = 0;
     QString language;
     QString languageVariant;
     QString country;
@@ -32,14 +32,12 @@ class Q_DECL_HIDDEN Blog::Private
 };
 
 Blog::Private::Private()
-    : postsCount(0)
-    , pagesCount(0)
 {
 }
 
 Blog::Blog()
-  : Object()
-  , d(new Private)
+    : Object()
+    , d(new Private)
 {
 }
 
@@ -108,7 +106,6 @@ QVariant Blog::customMetaData() const
     return d->customMetaData;
 }
 
-
 BlogPtr Blog::Private::fromJSON(const QVariant &json)
 {
     BlogPtr blog(new Blog);
@@ -132,7 +129,6 @@ BlogPtr Blog::Private::fromJSON(const QVariant &json)
     return blog;
 }
 
-
 BlogPtr Blog::fromJSON(const QByteArray &rawData)
 {
     QJsonDocument document = QJsonDocument::fromJson(rawData);
